@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-helpers.c,v 1.19 2004/05/29 14:36:07 chpe Exp $
+ *  $Id: ephy-file-helpers.c,v 1.20.4.1 2004/10/02 14:23:18 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -72,8 +72,7 @@ char *
 ephy_file_downloads_dir (void)
 {
 	const char *translated_folder;
-	char *converted, *downloads_dir;
-	gboolean desktop_is_home;
+	char *desktop_dir, *converted, *downloads_dir;
 
 	/* The name of the default downloads folder */
 	translated_folder = _("Downloads");
@@ -81,21 +80,33 @@ ephy_file_downloads_dir (void)
 	converted = g_filename_from_utf8 (translated_folder, -1, NULL, 
 					  NULL, NULL);
 
+	desktop_dir = ephy_file_desktop_dir ();
+	downloads_dir = g_build_filename (desktop_dir, converted, NULL);
+
+	g_free (desktop_dir);
+	g_free (converted);
+
+	return downloads_dir;
+}
+
+char *
+ephy_file_desktop_dir (void)
+{
+	char *downloads_dir;
+	gboolean desktop_is_home;
+
 	desktop_is_home = eel_gconf_get_boolean (CONF_DESKTOP_IS_HOME_DIR);
 
 	if (desktop_is_home)
 	{
-		downloads_dir = g_build_filename
-			(g_get_home_dir (), converted, NULL);
+		downloads_dir = g_strdup (g_get_home_dir ()); 
 	}
 	else
 	{
 		downloads_dir = g_build_filename
-			(g_get_home_dir (), "Desktop", converted, NULL);
+			(g_get_home_dir (), "Desktop", NULL);
 	}
 
-	g_free (converted);
-
 	return downloads_dir;
 }
 
@@ -224,17 +235,25 @@ ephy_file_helpers_shutdown (void)
 	dot_dir = NULL;
 }
 
-void
+gboolean
 ephy_ensure_dir_exists (const char *dir)
 {
 	if (g_file_test (dir, G_FILE_TEST_IS_DIR) == FALSE)
 	{
 		if (g_file_test (dir, G_FILE_TEST_EXISTS) == TRUE)
-			g_error (_("%s exists, please move it out of the way."), dir);
+		{
+			g_warning (_("%s exists, please move it out of the way."), dir);
+			return FALSE;
+		}
 
 		if (mkdir (dir, 488) != 0)
-			g_error (_("Failed to create directory %s."), dir);
+		{
+			g_warning (_("Failed to create directory %s."), dir);
+			return FALSE;
+		}
 	}
+
+	return TRUE;
 }
 
 static void
