@@ -15,12 +15,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-search-entry.c,v 1.3 2003/09/01 23:20:11 chpe Exp $
+ *  $Id: ephy-search-entry.c,v 1.6 2004/03/17 09:02:38 marco Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <gtk/gtklabel.h>
-#include <config.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <string.h>
 
 #include "ephy-search-entry.h"
@@ -99,14 +102,10 @@ ephy_search_entry_class_init (EphySearchEntryClass *klass)
 static gboolean
 ephy_search_entry_timeout_cb (EphySearchEntry *entry)
 {
-	gdk_threads_enter ();
-
 	g_signal_emit (G_OBJECT (entry), ephy_search_entry_signals[SEARCH], 0,
 		       gtk_entry_get_text (GTK_ENTRY (entry)));
 	entry->priv->timeout = 0;
 
-	gdk_threads_leave ();
-
 	return FALSE;
 }
 
