@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-notebook.h,v 1.9 2004/06/19 17:21:19 marco Exp $
+ *  $Id: ephy-notebook.h,v 1.10 2004/08/06 14:34:07 chpe Exp $
  */
 
 #ifndef EPHY_NOTEBOOK_H
@@ -41,11 +41,6 @@ typedef struct EphyNotebookClass	EphyNotebookClass;
 typedef struct EphyNotebook		EphyNotebook;
 typedef struct EphyNotebookPrivate	EphyNotebookPrivate;
 
-enum
-{
-	EPHY_NOTEBOOK_ADD_LAST	= -1
-};
-
 struct EphyNotebook
 {
 	GtkNotebook parent;
