@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.206.4.1 2004/09/26 16:48:26 chpe Exp $
+ *  $Id: ephy-window.c,v 1.206.4.4 2004/10/05 18:05:47 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -52,6 +52,7 @@
 #include "ephy-stock-icons.h"
 #include "ephy-extension.h"
 #include "ephy-favicon-cache.h"
+#include "ephy-gui.h"
 
 #include <string.h>
 #include <glib/gi18n.h>
@@ -320,16 +321,8 @@ static guint ephy_popups_n_entries = G_N_ELEMENTS (ephy_popups_entries);
 
 #define EPHY_WINDOW_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_WINDOW, EphyWindowPrivate))
 
-typedef enum
-{
-	EPHY_WINDOW_MODE_NORMAL,
-	EPHY_WINDOW_MODE_FULLSCREEN,
-	EPHY_WINDOW_MODE_PRINT_PREVIEW
-} EphyWindowMode;
-
 struct EphyWindowPrivate
 {
-	EphyWindowMode mode;
 	GtkWidget *main_vbox;
 	GtkWidget *menu_dock;
 	GtkWidget *exit_fullscreen_popup;
@@ -346,14 +339,10 @@ struct EphyWindowPrivate
 	GtkNotebook *notebook;
 	EphyTab *active_tab;
 	EphyDialog *find_dialog;
-	gboolean closing;
-	gboolean has_size;
 	guint num_tabs;
 	guint tab_message_cid;
 	guint help_message_cid;
-
 	EphyEmbedChrome chrome;
-	gboolean should_save_chrome;
 
 	guint disable_arbitrary_url_notifier_id;
 	guint disable_bookmark_editing_notifier_id;
@@ -365,6 +354,12 @@ struct EphyWindowPrivate
 	guint disable_command_line_notifier_id;
 	guint browse_with_caret_notifier_id;
 	guint allow_popups_notifier_id;
+
+	gboolean closing : 1;
+	gboolean has_size : 1;
+	gboolean fullscreen_mode : 1;
+	gboolean ppv_mode : 1;
+	gboolean should_save_chrome : 1;
 };
 
 enum
@@ -505,21 +500,21 @@ get_chromes_visibility (EphyWindow *window, gboolean *show_menubar,
 {
 	EphyEmbedChrome flags = window->priv->chrome;
 
-	switch (window->priv->mode)
+	if (window->priv->ppv_mode)
 	{
-		case EPHY_WINDOW_MODE_NORMAL:
-			*show_menubar = (flags & EPHY_EMBED_CHROME_MENUBAR) != 0;
-			*show_statusbar = (flags & EPHY_EMBED_CHROME_STATUSBAR) != 0;
-			*show_toolbar = (flags & EPHY_EMBED_CHROME_TOOLBAR) != 0;
-			*show_bookmarksbar = (flags & EPHY_EMBED_CHROME_BOOKMARKSBAR) != 0;
-			break;
-		case EPHY_WINDOW_MODE_FULLSCREEN:
-			*show_toolbar = (flags & EPHY_EMBED_CHROME_TOOLBAR) != 0;
-			*show_menubar = *show_statusbar = *show_bookmarksbar = FALSE;
-			break;
-		default:
-			*show_menubar = *show_statusbar = *show_toolbar = *show_bookmarksbar = FALSE;
-			break;
+		*show_menubar = *show_statusbar = *show_toolbar = *show_bookmarksbar = FALSE;
+	}
+	else if (window->priv->fullscreen_mode)
+	{
+		*show_toolbar = (flags & EPHY_EMBED_CHROME_TOOLBAR) != 0;
+		*show_menubar = *show_statusbar = *show_bookmarksbar = FALSE;
+	}
+	else
+	{
+		*show_menubar = (flags & EPHY_EMBED_CHROME_MENUBAR) != 0;
+		*show_statusbar = (flags & EPHY_EMBED_CHROME_STATUSBAR) != 0;
+		*show_toolbar = (flags & EPHY_EMBED_CHROME_TOOLBAR) != 0;
+		*show_bookmarksbar = (flags & EPHY_EMBED_CHROME_BOOKMARKSBAR) != 0;
 	}
 }
 
@@ -548,7 +543,7 @@ ephy_window_fullscreen (EphyWindow *window)
 {
 	GtkWidget *popup, *button, *icon, *label, *hbox;
 
-	window->priv->mode = EPHY_WINDOW_MODE_FULLSCREEN;
+	window->priv->fullscreen_mode = TRUE;
 
 	sync_chromes_visibility (window);
 
@@ -599,7 +594,7 @@ ephy_window_fullscreen (EphyWindow *window)
 static void
 ephy_window_unfullscreen (EphyWindow *window)
 {
-	window->priv->mode = EPHY_WINDOW_MODE_NORMAL;
+	window->priv->fullscreen_mode = FALSE;
 
 	destroy_exit_fullscreen_popup (window);
 
@@ -661,6 +656,8 @@ confirm_close_with_modified_forms (EphyWindow *window)
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      _("Close _Document"), GTK_RESPONSE_OK,
 					      NULL);
+
+	ephy_gui_set_default_window_icon (GTK_WINDOW (dialog));
 	
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
@@ -722,8 +719,12 @@ ephy_window_key_press_event (GtkWidget *widget,
 	GtkWidget *menubar;
 	guint modifiers = gtk_accelerator_get_default_mod_mask ();
 
-	/* Show and activate the menubar on F10, if it isn't visible */
-        if (event->keyval == GDK_F10 && (event->state & modifiers) == 0)
+	/* Show and activate the menubar on F10, if it isn't visible,
+	 * unless we're in ppv mode
+	 */
+        if (window->priv->ppv_mode == FALSE &&
+	    event->keyval == GDK_F10 &&
+	    (event->state & modifiers) == 0)
 	{
 		menubar = gtk_ui_manager_get_widget
 			(GTK_UI_MANAGER (window->ui_merge), "/menubar");
@@ -754,7 +755,7 @@ ephy_window_delete_event_cb (GtkWidget *widget, GdkEvent *event, EphyWindow *win
 	/* Workaround a crash when closing a window while in print preview mode. See
 	 * mozilla bug #241809
 	 */
-	if (window->priv->mode == EPHY_WINDOW_MODE_PRINT_PREVIEW)
+	if (window->priv->ppv_mode)
 	{
 		EphyEmbed *embed;
 
@@ -1557,7 +1558,7 @@ show_embed_popup (EphyWindow *window, EphyTab *tab, EphyEmbedEvent *event)
 	EphyEmbedEventType type;
 
 	/* Do not show the menu in print preview mode */
-	if (window->priv->mode == EPHY_WINDOW_MODE_PRINT_PREVIEW)
+	if (window->priv->ppv_mode)
 	{
 		return;
 	}
@@ -2161,7 +2162,8 @@ ephy_window_init (EphyWindow *window)
 	window->priv->has_size = FALSE;
 	window->priv->chrome = EPHY_EMBED_CHROME_ALL;
 	window->priv->should_save_chrome = FALSE;
-	window->priv->mode = EPHY_WINDOW_MODE_NORMAL;
+	window->priv->fullscreen_mode = FALSE;
+	window->priv->ppv_mode = FALSE;
 
 	ensure_default_icon ();
 
@@ -2386,16 +2388,12 @@ void
 ephy_window_set_print_preview (EphyWindow *window, gboolean enabled)
 {
 	GtkAccelGroup *accel_group;
-	EphyWindowMode mode;
 
 	accel_group = gtk_ui_manager_get_accel_group (GTK_UI_MANAGER (window->ui_merge));
 
-	mode = enabled ? EPHY_WINDOW_MODE_PRINT_PREVIEW :
-			 EPHY_WINDOW_MODE_NORMAL;
+	if (window->priv->ppv_mode == enabled) return;
 
-	if (mode == window->priv->mode) return;
-
-	window->priv->mode = mode;
+	window->priv->ppv_mode = enabled;
 
 	sync_chromes_visibility (window);
 	ephy_notebook_set_show_tabs (EPHY_NOTEBOOK (window->priv->notebook), !enabled);
